referrerpolicy=no-referrer-when-downgrade

Proxies

Type Alias Proxies 

pub type Proxies<T: Config> = StorageMap<_GeneratedPrefixForStorageProxies<T>, Twox64Concat, T::AccountId, (BoundedVec<ProxyDefinition<T::AccountId, T::ProxyType, BlockNumberFor<T>>, T::MaxProxies>, <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance), ValueQuery>;
The set of account proxies. Maps the account which has delegated to the accounts which are being delegated to, together with the amount held on deposit.

Storage type is [StorageMap] with key type T :: AccountId and value type (BoundedVec < ProxyDefinition < T :: AccountId, T :: ProxyType, BlockNumberFor < T > > , T :: MaxProxies, > , BalanceOf < T > ,).

Aliased Type

pub struct Proxies<T: Config>(/* private fields */);